@@ -1,21 +1,21 @@
-/* about.c - about dialog for sciteproj
+/* about.c - about dialog for SciteProj
  *
- *	 Copyright 2008,2009,2010 Andreas Ronnquist
+ *	 Copyright 2008-2011 Andreas Ronnquist
  *
- * This file is part of Sciteproj.
+ * This file is part of SciteProj.
  * 
- * Sciteproj is free software: you can redistribute it and/or modify
+ * SciteProj is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Sciteproj is distributed in the hope that it will be useful,
+ * SciteProj is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Sciteproj.  If not, see <http://www.gnu.org/licenses/>.
+ * along with SciteProj.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -27,23 +27,23 @@
 #include "graphics.h"
 
 
-static gchar *sLicense =	(gchar*)"Sciteproj is free software: you can redistribute it and/or modify\n"
+static gchar *sLicense =	(gchar*)"SciteProj is free software: you can redistribute it and/or modify\n"
 											  "it under the terms of the GNU General Public License as published by\n"
 											  "the Free Software Foundation, either version 3 of the License, or\n"
 											  "(at your option) any later version.\n"
 											  "\n"
-											  "Sciteproj is distributed in the hope that it will be useful,\n"
+											  "SciteProj is distributed in the hope that it will be useful,\n"
 											  "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
 											  "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
 											  "GNU General Public License for more details.\n"
 											  "\n"
 											  "You should have received a copy of the GNU General Public License\n"
-											  "along with Sciteproj.  If not, see <http://www.gnu.org/licenses/>.\n";
+											  "along with SciteProj.  If not, see <http://www.gnu.org/licenses/>.\n";
 
 
 gchar *homepage_string=(gchar*)"http://sciteproj.gusnan.se";
 
-gchar *sVersion = (gchar*)"0.3.22";
+gchar *sVersion = (gchar*)"0.4.00";
 
 /**
  *	show_about_dialog
@@ -202,9 +202,7 @@ void show_about_dialog()
 	g_object_unref(tag);
 	
 	
-#ifdef __DEBUG
-	g_free(debug_string);
-	
+#ifdef _DEBUG
 	g_object_unref(debug_tag);
 #endif
 }
