@@ -1,25 +1,25 @@
-/* about.h - about dialog for sciteproj
+/* about.h - about dialog for SciteProj
  *
- *	 Copyright 2008,2009,2010 Andreas Ronnquist
+ *	 Copyright 2008-2011 Andreas Ronnquist
  *
- * This file is part of Sciteproj.
+ * This file is part of SciteProj.
  * 
- * Sciteproj is free software: you can redistribute it and/or modify
+ * SciteProj is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Sciteproj is distributed in the hope that it will be useful,
+ * SciteProj is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Sciteproj.  If not, see <http://www.gnu.org/licenses/>.
+ * along with SciteProj.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef __ABOUT_HEADER_
-#define __ABOUT_HEADER_
+#ifndef __HEADER_ABOUT_
+#define __HEADER_ABOUT_
 
 /* extern gchar *sVersion;*/
 
@@ -29,4 +29,4 @@ void show_usage_dialog();
 void show_version();
 
 
-#endif /*__ABOUT_HEADER_*/
+#endif /*__HEADER_ABOUT_*/
