@@ -1,21 +1,21 @@
-/* folder_to_xml.c - file system to xml convertion for sciteproj
+/* folder_to_xml.c - file system to xml convertion for SciteProj
  *
- *  Copyright 2009,2010 Andreas Ronnquist
+ *  Copyright 2009-2011 Andreas Ronnquist
  *
- * This file is part of Sciteproj.
+ * This file is part of SciteProj.
  * 
- * Sciteproj is free software: you can redistribute it and/or modify
+ * SciteProj is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Sciteproj is distributed in the hope that it will be useful,
+ * SciteProj is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Sciteproj.  If not, see <http://www.gnu.org/licenses/>.
+ * along with SciteProj.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -55,9 +55,11 @@ gchar *get_short_folder_name(gchar *base,gchar *current)
 	}
 	
 	// make sure the returned string don't start with a dir separator
-	if (result[0]==G_DIR_SEPARATOR) {
-		result++;
-	}
+	co=0;
+	do {
+		if (result[0]==G_DIR_SEPARATOR) result++;
+		co++;
+	} while ((result[0]==G_DIR_SEPARATOR) && (co<(int)(strlen(base))));
 		
 	return result;
 }
@@ -114,6 +116,7 @@ gboolean traverse_folder(gchar *folder,int *indent,gboolean ignore_hidden,int ma
 	
 	if (g_str_has_suffix(trimmed,suffix_string)) {
 		
+		g_free(trimmed);
 		trimmed=g_strndup(folder,strlen(folder)-1);
 	}
 	
