@@ -1,27 +1,27 @@
-/* folder_to_xml.h - file system to xml convertion for sciteproj
+/* folder_to_xml.h - file system to xml convertion for SciteProj
  *
- *  Copyright 2009,2010 Andreas Ronnquist
+ *  Copyright 2009-2011 Andreas Ronnquist
  *
- * This file is part of Sciteproj.
+ * This file is part of SciteProj.
  * 
- * Sciteproj is free software: you can redistribute it and/or modify
+ * SciteProj is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Sciteproj is distributed in the hope that it will be useful,
+ * SciteProj is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Sciteproj.  If not, see <http://www.gnu.org/licenses/>.
+ * along with SciteProj.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef __FOLDER_TO_XML_HEADER_
-#define __FOLDER_TO_XML_HEADER_
+#ifndef __HEADER_FOLDER_TO_XML_
+#define __HEADER_FOLDER_TO_XML_
 
 gboolean folder_to_xml(gchar *folder,gchar *save_filename,int max_depth);
 
 
-#endif /*__FOLDER_TO_XML_HEADER_*/
+#endif /*__HEADER_FOLDER_TO_XML_*/
