@@ -1,25 +1,25 @@
-/* graphics.h - graphics code for sciteproj
+/* graphics.h - graphics code for SciteProj
  *
- *  Copyright 2009 Andreas Ronnquist
+ *  Copyright 2009-2011 Andreas Ronnquist
  *
- * This file is part of Sciteproj.
+ * This file is part of SciteProj.
  * 
- * Sciteproj is free software: you can redistribute it and/or modify
+ * SciteProj is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Sciteproj is distributed in the hope that it will be useful,
+ * SciteProj is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Sciteproj.  If not, see <http://www.gnu.org/licenses/>.
+ * along with SciteProj.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef __GRAPHICS_HEADER_
-#define __GRAPHICS_HEADER_
+#ifndef __HEADER_GRAPHICS_
+#define __HEADER_GRAPHICS_
 
 /**
  *
@@ -39,4 +39,4 @@ extern GdkCursor *standard_cursor;
 extern GdkCursor *busy_cursor;
 
 
-#endif /*__GRAPHICS_HEADER_*/
+#endif /*__HEADER_GRAPHICS_*/
