@@ -1,24 +1,31 @@
-/* gui.c - GUI code for sciteproj
+/* gui.c - GUI code for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009,2010 Andreas Ronnquist
+ *  Copyright 2006 Roy Wood, 2009-2011 Andreas Ronnquist
  *
- * This file is part of Sciteproj.
+ * This file is part of SciteProj.
  * 
- * Sciteproj is free software: you can redistribute it and/or modify
+ * SciteProj is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Sciteproj is distributed in the hope that it will be useful,
+ * SciteProj is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Sciteproj.  If not, see <http://www.gnu.org/licenses/>.
+ * along with SciteProj.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
+#include <string.h>
+#include <sys/stat.h>
+#include <glib.h>
+#include <gtk/gtk.h>
+
+#include <gdk/gdkkeysyms.h>
+
 #include <stdlib.h>
 
 #include "gui.h"
@@ -33,15 +40,11 @@
 #include "properties_dialog.h"
 #include "file_utils.h"
 
-#include <string.h>
-#include <sys/stat.h>
-#include <glib.h>
-#include <gtk/gtk.h>
-
-#include <gdk/gdkkeysyms.h>
-
 #include "search.h"
 #include "rename.h"
+#include "clipboard.h"
+
+#include "menus.h"
 
 
 #define APP_SCITEPROJ_ERROR g_quark_from_static_string("APP_GUI_ERROR")
@@ -83,7 +86,7 @@ static void removeitem_menu_cb();
 static void sort_ascending_cb();
 static void sort_descending_cb();
 
-static void copy_filename_to_clipboard_cb();
+gboolean tree_view_search_equal_func(GtkTreeModel *model,gint column,const gchar *key,GtkTreeIter *iter,gpointer search_data);
 
 static void edit_options_cb();
 
@@ -94,59 +97,6 @@ gboolean key_press_cb(GtkWidget *widget, GdkEventKey *event, gpointer userData);
 gchar *window_saved_title=NULL;
 
 
-// Menu definitions
-
-static gchar *sMenuDefXML = (gchar*)\
-	"<ui> \
-		<menubar> \
-			<menu name=\"FileMenu\" action=\"FileMenuAction\"> \
-				<menuitem name=\"OpenProjectItem\" action=\"OpenProjectAction\" /> \
-				<menuitem name=\"SaveProjectItem\" action=\"SaveProjectAction\" /> \
-				<menuitem name=\"SaveProjectAsItem\" action=\"SaveProjectAsAction\" /> \
-				<separator/> \
-				<menuitem name=\"ExitItem\" action=\"ExitAction\" /> \
-			</menu> \
-			<menu name=\"EditMenu\" action=\"EditMenuAction\"> \
-				<menuitem name=\"CreateGroupItem\" action=\"CreateGroupAction\" /> \
-				<menuitem name=\"AddFileItem\" action=\"AddFileAction\" /> \
-				<menuitem name=\"RemoveFileItem\" action=\"RemoveFileAction\"/> \
-				<separator/> \
-				<menuitem name=\"ExpandAllGroupsItem\" action=\"ExpandAllGroupsAction\" /> \
-				<menuitem name=\"CollapseAllGroupsItem\" action=\"CollapseAllGroupsAction\" /> \
-				<separator/> \
-				<menuitem name=\"Edit Options\" action=\"EditOptionsAction\" /> \
-			</menu> \
-			<menu name=\"HelpMenu\" action=\"HelpMenuAction\"> \
-				<menuitem name=\"UsageItem\" action=\"UsageAction\"/> \
-				<menuitem name=\"AboutItem\" action=\"AboutAction\"/> \
-			</menu> \
-		</menubar> \
-		<popup name=\"GeneralPopup\" action=\"GeneralPopupAction\"> \
-			<menuitem name=\"AddFilesPopupItem\" action=\"AddFilesPopupAction\"/> \
-			<menuitem name=\"AddGroupPopupItem\" action=\"AddGroupPopupAction\"/> \
-		</popup> \
-		<popup name=\"FilePopup\" action=\"FilePopupAction\"> \
-			<menuitem name=\"OpenFilePopupItem\" action=\"OpenFilePopupAction\"/> \
-			<menuitem name=\"RemoveFilePopupItem\" action=\"RemoveFilePopupAction\"/> \
-			<menuitem name=\"CopyFilenameToClipBoard\" action=\"CopyFilenameToClipBoardAction\"/> \
-			<separator/> \
-			<menuitem name=\"PropertiesPopupItem\" action=\"PropertiesPopupAction\"/> \
-		</popup> \
-		<popup name=\"GroupPopup\" action=\"GroupPopupAction\"> \
-			<menuitem name=\"AddFilesToGroupPopupItem\" action=\"AddFilestoGroupPopupAction\"/> \
-			<menuitem name=\"AddSubgroupPopupItem\" action=\"AddSubgroupPopupAction\"/> \
-			<menuitem name=\"RenameGroupPopupItem\" action=\"RenameGroupPopupAction\"/> \
-			<menuitem name=\"RemoveGroupPopupItem\" action=\"RemoveGroupPopupAction\"/> \
-			<separator/> \
-			<menuitem name=\"SortAscendingItem\" action=\"SortAscendingAction\"/> \
-			<menuitem name=\"SortDescendingItem\" action=\"SortDescendingAction\"/> \
-			<separator/> \
-			<menuitem name=\"ProperiesGroupPopupItem\" action=\"PropertiesGroupPopupAction\"/> \
-		</popup> \
-	</ui>";
-
-
-
 static GtkActionEntry sMenuActions[] = 
 {
 	{ "FileMenuAction", NULL, "_File" },
@@ -267,14 +217,11 @@ gboolean setup_gui(GError **err)
 		goto EXITPOINT;
 	}
 	
-	
 	gtk_container_add(GTK_CONTAINER(sMainWindow), vbox);
 	
-	
-	
 	// Create menus
 	
-	if (!(sActionGroup = gtk_action_group_new("SciteprojActions"))) {
+	if (!(sActionGroup = gtk_action_group_new("SciteProjActions"))) {
 		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create GtkActionGroup, gtk_action_group_new() = NULL", __func__);
 		
 		goto EXITPOINT;
@@ -286,7 +233,6 @@ gboolean setup_gui(GError **err)
 		goto EXITPOINT;
 	}
 	
-
 	g_signal_connect(sGtkUIManager, "add_widget", G_CALLBACK(menu_add_widget_cb), vbox);
 	
 	gtk_action_group_add_actions(sActionGroup, sMenuActions, sNumMenuActions, NULL);
@@ -300,21 +246,18 @@ gboolean setup_gui(GError **err)
 	}
 	
 	gtk_ui_manager_ensure_update(sGtkUIManager);
-	
-	
+		
 	// Activate the keyboard accelerators
 	
 	accelgroup = gtk_ui_manager_get_accel_group(sGtkUIManager);
 	gtk_window_add_accel_group(GTK_WINDOW(sMainWindow), accelgroup);
-	
-	
+		
 	// Create popup menus (shown when user right-clicks in gui elements)
 	
 	sGeneralPopupMenu = gtk_ui_manager_get_widget(sGtkUIManager, "/ui/GeneralPopup");
 	sGroupPopupMenu = gtk_ui_manager_get_widget(sGtkUIManager, "/ui/GroupPopup");
 	sFilePopupMenu = gtk_ui_manager_get_widget(sGtkUIManager, "/ui/FilePopup");
-	
-	
+		
 	// Add a scrolled window to the main window
 	
 	if (!(scrolledWindow = gtk_scrolled_window_new(NULL, NULL))) {
@@ -325,29 +268,28 @@ gboolean setup_gui(GError **err)
 	
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledWindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
 	
-	
 	gtk_box_pack_start(GTK_BOX(vbox), scrolledWindow, TRUE, TRUE, 0);
 
 	GtkWidget *hbox;
 	
 	hbox=gtk_hbox_new(FALSE,0);
 	
-	if (!init_statusbar(hbox,err)) {
+	if (!init_statusbar(hbox,&tempErr)) {
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not init statusbar", tempErr->message);
 		goto EXITPOINT;
 	}
 	
 	gtk_widget_show(hbox);
 	
 	gtk_box_pack_end(GTK_BOX(vbox),hbox,FALSE,TRUE,0);
-	
-	
+		
 	// Create the tree datastore
 	
-	if ((treeStore = get_treestore(err)) == NULL) {
+	if ((treeStore = create_treestore(&tempErr)) == NULL) {
+		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create the treestore", tempErr->message);
 		goto EXITPOINT;
 	}
-	
-	
+		
 	// Create the treeview, set it up to render the tree datastore, and add it to the hbox
 	
 	if (!(sTreeView = gtk_tree_view_new_with_model(GTK_TREE_MODEL(treeStore)))) {
@@ -356,6 +298,10 @@ gboolean setup_gui(GError **err)
 		goto EXITPOINT;
 	}
 	
+	g_object_unref(G_OBJECT(treeStore));
+	
+	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(sTreeView),TRUE);
+	
 	if (!(textCellRenderer = gtk_cell_renderer_text_new())) {
 		g_set_error(err, APP_SCITEPROJ_ERROR, -1, "%s: Could not create GtkCellRenderer, gtk_cell_renderer_text_new() = NULL", __func__);
 		
@@ -403,8 +349,7 @@ gboolean setup_gui(GError **err)
 	gtk_tree_view_append_column(GTK_TREE_VIEW(sTreeView), column2);
 	
 	gtk_container_add(GTK_CONTAINER(scrolledWindow), sTreeView);
-	
-	
+		
 	// Get tree events
 	
 	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(sTreeView));
@@ -412,6 +357,7 @@ gboolean setup_gui(GError **err)
 	
 	g_signal_connect(G_OBJECT(sTreeView), "row-activated", G_CALLBACK(tree_row_activated_cb), NULL);
 	
+	gtk_tree_view_set_search_equal_func(GTK_TREE_VIEW(sTreeView),tree_view_search_equal_func,NULL,NULL);
 	
 	gtk_tree_view_enable_model_drag_source(GTK_TREE_VIEW(sTreeView), GDK_BUTTON1_MASK, dragTargets, 1, GDK_ACTION_MOVE);
 	gtk_tree_view_enable_model_drag_dest(GTK_TREE_VIEW(sTreeView), dragTargets, 1, GDK_ACTION_MOVE);
@@ -430,9 +376,7 @@ gboolean setup_gui(GError **err)
 	
 	g_signal_connect(G_OBJECT(sTreeView), "button-press-event", G_CALLBACK(mouse_button_pressed_cb), sTreeView);
  	g_signal_connect(G_OBJECT(sTreeView), "key-press-event", G_CALLBACK(key_press_cb), sTreeView);
-	
-	
-	
+		
 		
 	gtk_window_resize(GTK_WINDOW(sMainWindow), gPrefs.width, gPrefs.height);
 	gtk_window_move(GTK_WINDOW(sMainWindow),gPrefs.xpos,gPrefs.ypos);
@@ -463,7 +407,7 @@ void gui_close()
 	
 	if (scrolledWindow) gtk_widget_destroy(scrolledWindow);
 	
-	unref_tree_graphics();
+	//unref_tree_graphics();
 	
 	unload_graphics();
 	
@@ -539,10 +483,6 @@ void set_save_button_sensitivity(gboolean enabled)
 }
 
 
-
-
-
-
 /**
  * Callback for Gtk "delete_event" message for the top-level application window.
  *
@@ -592,9 +532,6 @@ static void switch_folder_icon(GtkTreeView *treeView,GtkTreePath *path)
 	}
 	
 	g_free(relFilePath);
-	
-	
-	
 }
 
 /**
@@ -702,11 +639,9 @@ static gboolean mouse_button_pressed_cb(GtkWidget *treeView, GdkEventButton *eve
 	gint nodeItemType;
 	GtkTreeIter iter;
 	
-	
 	g_assert(treeView != NULL);
 	g_assert(event != NULL);
 	
-	
 	// Until we know for sure, assume that the user has not clicked on a node
 	
 	clicked_node.valid=FALSE;
@@ -778,7 +713,6 @@ static gboolean mouse_button_pressed_cb(GtkWidget *treeView, GdkEventButton *eve
 		gtk_menu_popup(GTK_MENU(sGroupPopupMenu), NULL, NULL, NULL, NULL, event->button, gdk_event_get_time((GdkEvent*) event));
 	}
 	
-	
 	// We took care of the event, so no need to propogate it
 	
 	eventHandled = TRUE;
@@ -806,7 +740,6 @@ static void sort_ascending_cb()
 
 	sort_children(&(clicked_node.iter),&err,compare_strings_smaller);
 	
-	
 EXITPOINT:
 	//
 	if (err) g_error_free(err);
@@ -847,8 +780,7 @@ static void popup_add_files_cb()
 	if (clicked_node.valid && clicked_node.type == ITEMTYPE_FILE) {
 		goto EXITPOINT;
 	}
-	
-	
+		
 	// Add to the root or to a group?
 	
 	if (clicked_node.valid) {
@@ -942,8 +874,7 @@ static void popup_open_file_cb()
 		
 		gtk_tree_selection_selected_foreach (tree_selection, _selected_helper, NULL);
 	}
-	
-	
+		
 	// We can only open files
 	
 	if (!clicked_node.valid || clicked_node.type != ITEMTYPE_FILE) {
@@ -978,19 +909,17 @@ void remove_selected_items ( GtkTreeView *treeview )
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 
-	GtkTreeStore *store;
+	//GtkTreeStore *store;
 	
 	GError *error=NULL;
    
 	if (gtk_tree_selection_count_selected_rows(selection) == 0)
 		return;
-   
+	
+	model=gtk_tree_view_get_model(treeview);
+
 	GList *list = gtk_tree_selection_get_selected_rows( selection, &model );
 
-	store = get_treestore(NULL);
-
-	model=GTK_TREE_MODEL(store);
-
 	int nRemoved = 0;
 	
 	// Begin at the end and go to the start
@@ -1144,16 +1073,12 @@ static void popup_add_group_cb()
 {
 	GtkTreeIter *nodeIter = NULL;
 	
-	
 	// Groups cannot be added to files!
-	
 	if (clicked_node.valid && clicked_node.type == ITEMTYPE_FILE) {
 		goto EXITPOINT;
 	}
-	
-	
+		
 	// Are we adding this to the root of the tree, or to an existing group?
-	
 	if (clicked_node.valid) {
 		nodeIter = &(clicked_node.iter);
 	}
@@ -1236,7 +1161,6 @@ static void ask_name_add_group(GtkTreeIter *nodeIter)
 	
 	
 	// Create a dialog box with a nicely-centered text entry widget
-	
 	dialog = gtk_dialog_new_with_buttons("Choose Group Name", NULL, GTK_DIALOG_MODAL, GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
 	
 	g_signal_connect(dialog, "response",  G_CALLBACK(gtk_widget_hide), dialog);
@@ -1305,7 +1229,6 @@ EXITPOINT:
 
 static void fix_folders_step_through(GtkTreeView *tree_view, GtkTreeIter newiter,GtkTreePath *tree_path)
 {
-	//g_printf("HEJ!\n");
 	GtkTreeModel *tree_model = gtk_tree_view_get_model(tree_view);
 	
 	gchar *relFilePath;
@@ -1506,7 +1429,7 @@ static void addfile_menu_cb()
 	
 	GtkTreeSelection *treeSelection = gtk_tree_view_get_selection(GTK_TREE_VIEW(sTreeView));
 	
-	GtkTreeModel *tree_model=GTK_TREE_MODEL(get_treestore(&err));
+	GtkTreeModel *tree_model=gtk_tree_view_get_model(GTK_TREE_VIEW(sTreeView)); //GTK_TREE_MODEL(get_treestore(&err));
 	
 	list = gtk_tree_selection_get_selected_rows(treeSelection, NULL);
 	
@@ -1632,7 +1555,7 @@ gboolean key_press_cb(GtkWidget *widget, GdkEventKey *event, gpointer userData)
 
 
 /**
- *
+ *		Expands all folders
  */
 static gboolean foreach_expand(GtkTreeModel *model,GtkTreePath *path,GtkTreeIter *iter,gpointer data)
 {
@@ -1641,7 +1564,7 @@ static gboolean foreach_expand(GtkTreeModel *model,GtkTreePath *path,GtkTreeIter
 }
 
 /**
- *
+ *		Collapses all folders
  */
 static gboolean foreach_collapse(GtkTreeModel *model,GtkTreePath *path,GtkTreeIter *iter,gpointer data)
 {
@@ -1654,9 +1577,7 @@ static gboolean foreach_collapse(GtkTreeModel *model,GtkTreePath *path,GtkTreeIt
  */
 static void expand_all_items_cb()
 {
-	GtkTreeStore *tree_store=get_treestore(NULL);
-	
-	gtk_tree_model_foreach(GTK_TREE_MODEL(tree_store),foreach_expand,NULL);
+	gtk_tree_model_foreach(gtk_tree_view_get_model(GTK_TREE_VIEW(sTreeView)),foreach_expand,NULL);
 }
 
 
@@ -1665,9 +1586,7 @@ static void expand_all_items_cb()
  */
 static void collapse_all_items_cb()
 {
-	GtkTreeStore *tree_store=get_treestore(NULL);
-	
-	gtk_tree_model_foreach(GTK_TREE_MODEL(tree_store),foreach_collapse,NULL);
+	gtk_tree_model_foreach(gtk_tree_view_get_model(GTK_TREE_VIEW(sTreeView)),foreach_collapse,NULL);
 }
 
 
@@ -1708,67 +1627,6 @@ void edit_options_cb()
 
 
 
-/**
- * Copies the filename including full folder to the clipboard
- */
-void copy_filename_to_clipboard(GtkTreeModel *model, GtkTreeIter *iter)
-{
-	GError *err=NULL;
-	
-	gchar *nodename=NULL;
-	gchar *filePath=NULL;
-	int nodeType=-1;
-	
-	gtk_tree_model_get(model, iter, COLUMN_FILENAME, &nodename, COLUMN_ITEMTYPE, &nodeType, COLUMN_FILEPATH, &filePath, -1);
-	
-	gchar *absFilePath = NULL; //g_strdup_printf("%s",filePath);
-		
-	// filePath is NULL?
-	//if (!relative_path_to_abs_path(sClickedNodeName, &absFilePath, get_project_directory(), &err)) {
-	
-	if (!relative_path_to_abs_path(filePath, &absFilePath, get_project_directory(), &err)) {
-		goto EXITPOINT;
-	}
-	
-	GdkDisplay *display=gdk_display_get_default();
-	
-	GtkClipboard *clipboard=gtk_clipboard_get_for_display(display,GDK_SELECTION_CLIPBOARD);
-	
-	gtk_clipboard_set_text(clipboard,absFilePath,-1);
-	
-EXITPOINT:
-	
-	if (err) g_error_free(err);
-}
-
-
-/**
- * Callback for the menu item
- */
-void copy_filename_to_clipboard_cb()
-{
-	gint selected_rows=0;
-	gboolean multiple_selected=FALSE;
-	
-	GtkTreeSelection *treeSelect;
-	
-	treeSelect=gtk_tree_view_get_selection(GTK_TREE_VIEW(sTreeView));
-	
-	selected_rows=gtk_tree_selection_count_selected_rows(treeSelect);
-	if (selected_rows>1) {
-		multiple_selected=TRUE;
-	}
-		
-	if (!clicked_node.valid || clicked_node.type != ITEMTYPE_FILE) {
-		//goto EXITPOINT;
-	} else {
-		copy_filename_to_clipboard(gtk_tree_view_get_model(GTK_TREE_VIEW(sTreeView)),&(clicked_node.iter));
-		
-	}
-}
-
-
-
 /**
  *
  */
@@ -1776,3 +1634,24 @@ GtkWidget *get_main_window()
 {
 	return sMainWindow;
 }
+
+/**
+ *		search function for the gtk_tree_view_set_search_equal_func
+ *		@return TRUE when rows DONT match, FALSE when rows match
+ */
+gboolean tree_view_search_equal_func(GtkTreeModel *model,gint column,const gchar *key,GtkTreeIter *iter,gpointer search_data)
+{
+	gchar *filename;
+	// For some reason this should return TRUE if the row DONT match
+	gboolean res=TRUE;
+	
+	gtk_tree_model_get(model, iter, COLUMN_FILENAME, &filename, -1);
+	
+	// zero when matches, which means we should return FALSE
+	if (g_ascii_strncasecmp(key,filename,strlen(key))==0) res=FALSE;
+	
+	g_free(filename);
+
+	
+	return res;
+}
