@@ -1,29 +1,29 @@
-/* gui.h - GUI code for sciteproj
+/* gui.h - GUI code for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009 Andreas Ronnquist
+ *  Copyright 2006 Roy Wood, 2009-2011 Andreas Ronnquist
  *
- * This file is part of Sciteproj.
+ * This file is part of SciteProj.
  * 
- * Sciteproj is free software: you can redistribute it and/or modify
+ * SciteProj is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Sciteproj is distributed in the hope that it will be useful,
+ * SciteProj is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Sciteproj.  If not, see <http://www.gnu.org/licenses/>.
+ * along with SciteProj.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef __GUI_HEADER_
-#define __GUI_HEADER_
-
-#include <gtk/gtk.h>
-
+#ifndef __HEADER_GUI_
+#define __HEADER_GUI_
 	
+/**
+ *
+ */
 struct ClickedNode
 {
 	gboolean valid;
@@ -34,6 +34,13 @@ struct ClickedNode
 
 typedef struct ClickedNode ClickedNode;
 
+/**
+ * Variables
+ */
+extern gchar *window_saved_title;
+extern GtkWidget *sTreeView;
+extern ClickedNode clicked_node;
+
 
 // Initialize the GUI
 gboolean setup_gui(GError **err);
@@ -57,12 +64,7 @@ void get_dimensions(gint *left, gint *top, gint *width, gint *height);
 
 void update_project_is_dirty(gboolean dirty);
 
-extern gchar *window_saved_title;
-extern GtkWidget *sTreeView;
-
-extern ClickedNode clicked_node;
-
 GtkWidget *get_main_window();
 
 
-#endif /*__GUI_HEADER_*/
+#endif /*__HEADER_GUI_*/
