@@ -1,25 +1,25 @@
-/* prefs.h - prefs for sciteproj
+/* prefs.h - prefs for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009 Andreas Ronnquist
+ *  Copyright 2006 Roy Wood, 2009-2011 Andreas Ronnquist
  *
- * This file is part of Sciteproj.
+ * This file is part of SciteProj.
  * 
- * Sciteproj is free software: you can redistribute it and/or modify
+ * SciteProj is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Sciteproj is distributed in the hope that it will be useful,
+ * SciteProj is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Sciteproj.  If not, see <http://www.gnu.org/licenses/>.
+ * along with SciteProj.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef __PREFS_HEADER_
-#define __PREFS_HEADER_
+#ifndef __HEADER_PREFS_
+#define __HEADER_PREFS_
 
 #define PREFS_BUFSIZE 256
 
@@ -50,4 +50,4 @@ extern sciteproj_prefs gPrefs;
 
 gboolean init_prefs();
 
-#endif /*__PREFS_HEADER_*/
+#endif /*__HEADER_PREFS_*/
