@@ -1,25 +1,25 @@
-/* statusbar.h - statusbar for sciteproj
+/* statusbar.h - statusbar for SciteProj
  *
- *  Copyright 2009 Andreas Ronnquist
+ *  Copyright 2009-2011 Andreas Ronnquist
  *
- * This file is part of Sciteproj.
+ * This file is part of SciteProj.
  * 
- * Sciteproj is free software: you can redistribute it and/or modify
+ * SciteProj is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Sciteproj is distributed in the hope that it will be useful,
+ * SciteProj is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Sciteproj.  If not, see <http://www.gnu.org/licenses/>.
+ * along with SciteProj.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef __STATUSBAR_HEADER_
-#define __STATUSBAR_HEADER_
+#ifndef __HEADER_STATUSBAR_
+#define __HEADER_STATUSBAR_
 
 gboolean init_statusbar(GtkWidget *hbox,GError **err);
 
@@ -27,4 +27,4 @@ void set_statusbar_text(const gchar *text);
 
 void done_statusbar();
 
-#endif /*__STATUSBAR_HEADER_*/
+#endif /*__HEADER_STATUSBAR_*/
