@@ -1,25 +1,26 @@
-/* string_utils.c - misc string utils for sciteproj
+/* string_utils.c - misc string utils for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009 Andreas Ronnquist
+ *  Copyright 2006 Roy Wood, 2009-2011 Andreas Ronnquist
  *
- * This file is part of Sciteproj.
+ * This file is part of SciteProj.
  * 
- * Sciteproj is free software: you can redistribute it and/or modify
+ * SciteProj is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Sciteproj is distributed in the hope that it will be useful,
+ * SciteProj is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Sciteproj.  If not, see <http://www.gnu.org/licenses/>.
+ * along with SciteProj.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 #include <glib.h>
 #include <stdio.h>
+#include <ctype.h>
 
 #include "string_utils.h"
 #include "file_utils.h"
@@ -429,7 +430,8 @@ gboolean is_integer(gchar *string)
 	int co;
 	
 	for (co=0;co<(int)strlen(string);co++) {
-		if (string[co]<'0' || string[co]>'9') {
+		// returns zero if it isn't a digit
+		if (isdigit(string[co])==0) {
 			return FALSE;
 		}
 	}
