@@ -1,25 +1,25 @@
-/* string_utils.h - misc string utils for sciteproj
+/* string_utils.h - misc string utils for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009 Andreas Ronnquist
+ *  Copyright 2006 Roy Wood, 2009-2011 Andreas Ronnquist
  *
- * This file is part of Sciteproj.
+ * This file is part of SciteProj.
  * 
- * Sciteproj is free software: you can redistribute it and/or modify
+ * SciteProj is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Sciteproj is distributed in the hope that it will be useful,
+ * SciteProj is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Sciteproj.  If not, see <http://www.gnu.org/licenses/>.
+ * along with SciteProj.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef __STRING_UTILS_HEADER_
-#define __STRING_UTILS_HEADER_
+#ifndef __HEADER_STRING_UTILS_
+#define __HEADER_STRING_UTILS_
 
 
 
@@ -45,4 +45,4 @@ char *remove_newline( char *s );
 
 gboolean is_integer(gchar *string);
 
-#endif /*__STRING_UTILS_HEADER_*/
+#endif /*__HEADER_STRING_UTILS_*/
