@@ -1,23 +1,28 @@
-/* tree_manipulation.c - GtkTreeView manipulation code for sciteproj
+/* tree_manipulation.c - GtkTreeView manipulation code for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009 Andreas Ronnquist
+ *  Copyright 2006 Roy Wood, 2009-2011 Andreas Ronnquist
  *
- * This file is part of Sciteproj.
+ * This file is part of SciteProj.
  * 
- * Sciteproj is free software: you can redistribute it and/or modify
+ * SciteProj is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Sciteproj is distributed in the hope that it will be useful,
+ * SciteProj is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Sciteproj.  If not, see <http://www.gnu.org/licenses/>.
+ * along with SciteProj.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
+#include <glib.h>
+#include <gtk/gtk.h>
+
+#include <string.h>
+#include <sys/stat.h>
 
 
 #include "tree_manipulation.h"
@@ -27,12 +32,6 @@
 #include "prefs.h"
 
 
-#include <glib.h>
-#include <gtk/gtk.h>
-
-#include <string.h>
-#include <sys/stat.h>
-
 #include "gui.h"
 
 
@@ -52,7 +51,7 @@
 	
 
 
-static GtkTreeStore *sTreeStore = NULL;
+GtkTreeStore *sTreeStore = NULL;
 static gboolean sProjectIsDirty = FALSE;
 static gchar *sProjectFilepath = NULL;
 static gchar *sProjectDir = NULL;
@@ -112,7 +111,6 @@ static gboolean set_project_filepath(const gchar *filepath, GError **err)
 		};
 	}
 	
-	//windowTitle = g_strdup_printf("Sciteproj - %s", sProjectFilepath);
 	windowTitle=g_strdup_printf("%s",get_filename_from_full_path(sProjectFilepath));
 	
 	set_window_title(windowTitle);
@@ -158,7 +156,7 @@ const gchar* get_project_directory()
  *
  * @param err returns any error information
  */
-GtkTreeStore* get_treestore(GError **err)
+GtkTreeStore* create_treestore(GError **err)
 {
 	if (sTreeStore == NULL) {
 		sTreeStore = gtk_tree_store_new(COLUMN_EOL, TYPE_ITEMTYPE, TYPE_FILEPATH, TYPE_FILENAME, TYPE_FILESIZE, TYPE_FONTWEIGHT, TYPE_FONTWEIGHTSET, TYPE_ICON, TYPE_EXPANDED);
@@ -1266,30 +1264,3 @@ gboolean tree_contains(gchar *test_string)
 	return test.found;
 }
 
-
-/**
- *
- */
-gboolean unref_tree_graphics_foreach(GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer data)
-{
-	GdkPixbuf *buf;
-	gchar *filename;
-	
-	gtk_tree_model_get(model, iter, COLUMN_FILENAME, &filename, COLUMN_ICON, &buf, -1);
-	
-	g_object_unref(buf);
-	g_free(filename);
-
-	return FALSE;
-}
-
-/**
- *
- */
-void unref_tree_graphics()
-{
-	if (sTreeStore) {
-		gtk_tree_model_foreach(GTK_TREE_MODEL(sTreeStore),unref_tree_graphics_foreach,NULL);
-	}
-}
-
