@@ -1,27 +1,25 @@
-/* tree_manipulation.h - GtkTreeView manipulation code for sciteproj
+/* tree_manipulation.h - GtkTreeView manipulation code for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009 Andreas Ronnquist
+ *  Copyright 2006 Roy Wood, 2009-2011 Andreas Ronnquist
  *
- * This file is part of Sciteproj.
+ * This file is part of SciteProj.
  * 
- * Sciteproj is free software: you can redistribute it and/or modify
+ * SciteProj is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Sciteproj is distributed in the hope that it will be useful,
+ * SciteProj is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Sciteproj.  If not, see <http://www.gnu.org/licenses/>.
+ * along with SciteProj.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef __TREE_MANIPULATION_HEADER_
-#define __TREE_MANIPULATION_HEADER_
-
-#include <gtk/gtk.h>
+#ifndef __HEADER_TREE_MANIPULATION_
+#define __HEADER_TREE_MANIPULATION_
 
 
 // Node relative-position indicators
@@ -61,14 +59,14 @@ typedef gint(*StringCompareFunction)(gconstpointer,gconstpointer);
 
 
 // Get the GTKTreeStore
-GtkTreeStore* get_treestore(GError **err);
+GtkTreeStore* create_treestore(GError **err);
 
 // Get the project file directory
 const gchar* get_project_directory();
 gchar* get_project_filepath();
 
 // Clear the tree
-extern void empty_tree(GtkTreeStore *treeStore);
+void empty_tree(GtkTreeStore *treeStore);
 
 // Mark the project as dirty or clean (i.e. modified and in need of saving)
 void set_project_dirty_status(gboolean isDirty);
@@ -89,23 +87,23 @@ gboolean load_project(gchar *projectPath, GError **err);
 gboolean add_files_to_project(GtkTreeIter *parentIter, GError **err);
 
 // Add a file node to a GtkTreeModel
-extern gboolean add_tree_file(GtkTreeIter *currentIter, enum NodePosition position, const gchar* filepath, GtkTreeIter *newIter, gboolean makeRelative, GError **err);
+gboolean add_tree_file(GtkTreeIter *currentIter, enum NodePosition position, const gchar* filepath, GtkTreeIter *newIter, gboolean makeRelative, GError **err);
 
 //gboolean add_tree_filelist(GtkTreeIter *parentIter, GSList *fileList, GError **err);
 gboolean add_tree_filelist(GtkTreeIter *parentIter, GSList *fileList, GError **err);
 
 // Add a group node to a GtkTreeModel
-extern gboolean add_tree_group(GtkTreeIter *parentIter, enum NodePosition position, const gchar* groupname, gboolean expanded, GtkTreeIter *newIter, GError **err);
+gboolean add_tree_group(GtkTreeIter *parentIter, enum NodePosition position, const gchar* groupname, gboolean expanded, GtkTreeIter *newIter, GError **err);
 
 // Remove a node from a GtkTreeModel
-extern gboolean remove_tree_node(GtkTreeIter *iter, GError **err);
+gboolean remove_tree_node(GtkTreeIter *iter, GError **err);
 
 // Remove a node from a GtkTreeModel
-extern gboolean set_tree_node_name(GtkTreeIter *iter, const gchar *newContents, GError **err);
+gboolean set_tree_node_name(GtkTreeIter *iter, const gchar *newContents, GError **err);
 
-extern gboolean set_tree_node_expanded(GtkTreeIter *iter, gboolean expanded, GError **err);
+gboolean set_tree_node_expanded(GtkTreeIter *iter, gboolean expanded, GError **err);
 
-extern gboolean set_tree_node_icon(GtkTreeIter *iter, GdkPixbuf *pixbuf, GError **err);
+gboolean set_tree_node_icon(GtkTreeIter *iter, GdkPixbuf *pixbuf, GError **err);
 
 // Copy a node in the tree (including children)
 gboolean copy_tree_node(GtkTreeIter *srcIter, GtkTreeIter *dstIter, enum NodePosition position, GtkTreeIter *newIter, GError **err);
@@ -119,6 +117,4 @@ void sort_children(GtkTreeIter *node,GError **err,StringCompareFunction compare_
 
 gboolean tree_contains(gchar *value);
 
-void unref_tree_graphics();
-
-#endif /*__TREE_MANIPULATION_HEADER_*/
+#endif /*__HEADER_TREE_MANIPULATION_*/
